Imported code of the paper: [Faith and Fate: Limits of Transformers on Compositionality](https://arxiv.org/abs/2305.18654)
- Source: https://github.com/nouhadziri/faith-and-fate
- Authors: [Nouha Dziri](https://github.com/nouhadziri), et al.
- License: MIT

```bibtex
@article{dziri2023faith,
  title={Faith and Fate: Limits of Transformers on Compositionality},
  author={Dziri, Nouha and Lu, Ximing and Sclar, Melanie and Li, Xiang Lorraine and Jian, Liwei and Lin, Bill Yuchen and West, Peter and Bhagavatula, Chandra and Bras, Ronan Le and Hwang, Jena D and others},
  journal={arXiv preprint arXiv:2305.18654},
  year={2023}
}
```

The code was slightly adapted for reasoning-gym to produce stable results under hash-randomizaton.
